@@ -37,8 +37,7 @@ for my $exempt_sub (@exempt_subs) {
 }
 
 $bundle->remove_policy('ErrorHandling::RequireUseOfExceptions');
-
-#$bundle->remove_policy('CodeLayout::RequireUseUTF8');
+$bundle->remove_policy('CodeLayout::RequireUseUTF8');
 $bundle->remove_policy('Documentation::RequirePodLinksIncludeText');
 
 #$bundle->remove_policy('ErrorHandling::RequireCarping');
